@@ -11,16 +11,15 @@ from cognite.client.data_classes import (
     TransformationSchedule,
     TransformationUpdate,
 )
-from cognite.client.data_classes.transformations._alphatypes import AlphaDataModelInstances
-from cognite.client.data_classes.transformations.common import SequenceRows
+from cognite.client.data_classes.transformations.common import DataModelInstances, SequenceRows
 from cognite.client.exceptions import CogniteAPIError, CogniteDuplicatedError, CogniteNotFoundError
 
 from cognite.transformations_cli.commands.deploy.transformation_types import (
     ActionType,
-    AlphaDMIDestinationConfig,
     AuthConfig,
     DestinationConfig,
     DestinationConfigType,
+    DMIDestinationConfig,
     QueryConfig,
     RawDestinationConfig,
     ReadWriteAuthentication,
@@ -56,16 +55,18 @@ def to_transformation(
 def to_data_set_id(
     client: CogniteClient, data_set_id: Optional[int], data_set_external_id: Optional[str]
 ) -> Optional[int]:
+    err = ""
     if data_set_external_id:
         try:
             data_set = client.data_sets.retrieve(external_id=data_set_external_id)
-        except:
+        except CogniteAPIError as e:
+            err = f" ({e})"
             data_set = None
         if data_set:
             return data_set.id
         else:
             sys.exit(
-                f"Invalid data set external id, please verify if it exists or you have the required capability: {data_set_external_id}"
+                f"Invalid data set external id, please verify if it exists or you have the required capability: {data_set_external_id}{err}"
             )
     return data_set_id
 
@@ -81,8 +82,8 @@ def to_destination(destination: DestinationConfigType) -> TransformationDestinat
         return TransformationDestination.raw(destination.raw_database, destination.raw_table)
     elif isinstance(destination, SequenceRowsDestinationConfig):
         return SequenceRows(destination.external_id)
-    elif isinstance(destination, AlphaDMIDestinationConfig):
-        return AlphaDataModelInstances(
+    elif isinstance(destination, DMIDestinationConfig):
+        return DataModelInstances(
             destination.model_external_id, destination.space_external_id, destination.instance_space_external_id
         )
     else:
